# Beatles-albums
This package is a demo for my Python students and so I decided to give a tribute to The Beatles band, providing a list of their published Albums.
Enjoy this packge and listen to their masterpieces!
Added print "I love The Beatles"

Change log
==========

0.0.2 (8/05/2023)
-----------------
Second Release
Requires pandas module installation